#
# spec file for package ristretto
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ristretto
Version:        0.8.0
Release:        3.3
Summary:        Fast and Lightweight Image-viewer for the Xfce Desktop Environment
License:        GPL-2.0+
Group:          Productivity/Graphics/Viewers
Url:            http://goodies.xfce.org/projects/applications/ristretto
Source0:        http://archive.xfce.org/src/apps/ristretto/0.8/%{name}-%{version}.tar.bz2
# PATCH-FEATURE-OPENSUSE ristretto-add-mime-types.patch gber@opensuse.org -- Adds support for additional image MIME types supported by openSUSE
Patch0:         ristretto-add-mime-types.patch
# PATCH-FIX-UPSTREAM ristretto-fix-icon-installation.patch bxo#11614 gber@opensuse.org -- Fixes a typo causing the 128x128 icon to be installed into 48x48
Patch1:         ristretto-fix-icon-installation.patch
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  update-desktop-files
BuildRequires:  xfce4-dev-tools
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(exo-1)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libxfce4ui-1)
BuildRequires:  pkgconfig(libxfce4util-1.0)
BuildRequires:  pkgconfig(libxfconf-0)
BuildRequires:  pkgconfig(pkg-config)
Recommends:     %{name}-lang = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Ristretto is a fast and lightweight picture-viewer for the Xfce desktop environment.

%lang_package

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
xdt-autogen
%configure
make %{?_smp_mflags}

%install
%make_install

%suse_update_desktop_file -i ristretto GTK Graphics Viewer

%fdupes %{buildroot}%{_datadir}

%find_lang %{name} %{?no_lang_C}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS
%{_bindir}/ristretto
%{_datadir}/applications/ristretto.desktop
%{_datadir}/icons/hicolor/*/apps/ristretto.*
%dir %{_datadir}/appdata
%{_datadir}/appdata/ristretto.appdata.xml

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Sat Feb 28 2015 gber@opensuse.org
- update to version 0.8.0
  - use collate keys to handle filename sorting (bxo#9731)
  - add AppData file (bxo#11296)
  - fix invert zoom direction (bxo#10746)
  - update xfconf settings for Xfdesktop >= 4.11
  - check for thumbnails in the new location
  - don't check item->width twice (Bug 10534)
  - add version check because g_thread_init is deprecated
  - support shift+scroll to pan across an image
  - fixed an overflow when comparing filenames with large
    Numbers in them. (bxo#9485)
  - show filename before apptitle
  - fix bxo#8837 (Use thumbnail as appicon)
  - update the first image in the image-list when receiving
    a ready-signal.
  - translation updates
* Mon Aug  6 2012 gber@opensuse.org
- update to version 0.6.3
  - use thumbnail as appicon
  - update the first image in the image-list when receiving a
    ready-signal which is required to show the thumbnail once it's
    generated
* Mon Jul 30 2012 gber@opensuse.org
- update to version 0.6.2
  - fix a crash when configuring the 'limit-quality' property
  - translation updates
* Sun Apr 29 2012 gber@opensuse.org
- update to version 0.6.0
  - online documentation on http://docs.xfce.org/
  - the option to limit the maximum image-quality to the screen
    dimensions (to improve memory-usage and performance) - this
    was the default behaviour for 0.3, now ristretto renders at
    full quality with this option disabled
  - only one toolbar, instead of two
  - a quick-launch button on the toolbar to execute an editor
  - the option to pick a default-editor per mime-type
  - an optional clock that shows up when ristretto is fullscreen
  - ristretto now shows a 'Loading..' message in the statusbar, to
    indicate when it is busy
  - progressive loading of directories, prevent lockup of the UI
- added ristretto-fix-icon-installation.patch which fixes a typo
  causing the 128x128 icon to be installed into 48x48
* Sat Apr 28 2012 gber@opensuse.org
- update to version 0.3.7
  - reset adjustment-limits on closing the image (hide scrollbars)
  - remove call to gtk_message_dialog_get_message_area (> gtk 2.20)
  - improve rendering performance when closing a file
* Sun Apr  1 2012 gber@opensuse.org
- update to version 0.3.6
  - clear tooltip if image is closed
  - provide mime-type when loading image, gdkpixbufloader makes
    mistakes guessing it
  - keep a list of file-monitors for each file when a selection of
    files is opened
  - make a difference between delete from disk and send to trash
* Sat Mar 31 2012 gber@opensuse.org
- specfile cleanup
* Thu Mar 22 2012 gber@opensuse.org
- updated build dependencies
- split off -lang subpackage
* Sat Mar  3 2012 gber@opensuse.org
- update to version 0.3.5
  - do not use symbols from gtk+ > 2.20
  - report image-loading errors back to the user
  - fix ristretto.desktop mime-types list is incomplete)
- rebased ristretto-0.0.91-add-more-mime-types.patch as
  ristretto-add-mime-types.patch
- drop obsolete ristretto-0.3.4-fix-gtk-requirements.patch
* Sun Jan 29 2012 gber@opensuse.org
- added ristretto-0.3.4-fix-gtk-requirements.patch to only depend
  on GTK+ >= 2.20 (patch from upstream git)
* Sat Jan 28 2012 gber@opensuse.org
- update to version 0.3.4
  - do not use symbols from gtk+ > 2.20
  - autogenerate Changelog on make dist
  - update scale information when box-zoom is used
  - fix --fullscreen and --slideshow CLI options
* Sat Jan 14 2012 gber@opensuse.org
- update to version 0.3.2
  - apply saturation and brightness settings in the set-wallpaper
    preview widget
  - disable the sensitivity of the 'back' and 'forward' buttons
    when showing the first or last image in a list
  - improve preview of the set-wallpaper dialog
  - save the sorting algoritm
  - allow a directory to be passed in as a command-line argument
  - add back documentation
- removed obsolete ristretto-0.3.0-docs.tar.bz2 and
  ristretto-use-offline-documentation.patch
* Wed Jan 11 2012 gber@opensuse.org
- ristretto 0.3.1 requires GTK+ >= 2.24
* Tue Jan 10 2012 gber@opensuse.org
- update to version 0.3.1
  - do not open the copy of an image when saving
  - apply saturation and brightness settings in the set-wallpaper
    preview widget
  - add 'has-next' and 'has-previous' functions to disable the
    sensitivity of the 'back' and 'forward' buttons when showing
    the first or last image in a list
  - improve preview of the set-wallpaper dialog
  - make sure file-types unsupported by gdkpixbufloader are not
    accidently included in the image-list
  - save the sorting algoritm
  - limit rendering of selection-box to the inside of the image
  - allow a directory to be passed in as a command-line argument
  - bugfixes
  - translation updates
- added ristretto-0.3.0-docs.tar.bz2 and
  ristretto-use-offline-documentation.patch which add back the
  documentation
- removed obsolete
  ristretto-0.3.0-fix-no-return-in-nonvoid-function.patch
* Sun Nov 13 2011 gber@opensuse.org
- update to version 0.3.0
  - re-introduce autorotation based on the exif-orientation tag, a
    regression since 0.0.93
  - prevent segmentation fault when an error occurs while loading
    an image
  - port image-viewer to cairo
  - read the bgcolor properties on startup
  - let the file properties-dialog show file-properties.
  - add --settings cli-option to launch the settings-dialog.
  - add help->contents menuitem, launching documentation
  - add a user-manual
  - solve problem with size-calculation in size_prepared callback
  - set default height to 440px, Show all buttons on a vertically
    aligned navigationbar
  - show thumbnailbar by default
  - show toolbar when closing images in fullscreen-mode
  - improve background-color of monitor-chooser
  - make 'hide thumbnailbar fullscreen' the default
  - cleanup some memory-leaks
  - fix rounding error that generates continues rewrites of the
    main window
  - decrease buffersize when loading images, solves a problem with
    the JPEG pixbufloader
  - rotate thumbnails
- added ristretto-0.3.0-fix-no-return-in-nonvoid-function.patch in
  order to fix non-void function with no return statement
  (backported from upstream git)
* Sun Nov  6 2011 gber@opensuse.org
- update to version 0.2.3
  - fix bug #8097 (Scrolling to the right of a horizontal
    positioned thumbnailbar will make the images disappear)
  - decrease buffersize, prevents some pixbufloaders to behave
    oddly
* Sat Oct 29 2011 gber@opensuse.org
- update to version 0.2.2
  - fixes a bug with the scaling of images that causes the image to
    stretch horizontally under certain occasions
* Mon Oct 24 2011 gber@opensuse.org
- update to version 0.2.2
  - Version 0.1.1 and 0.2.0 had a bug that could cause ristretto to
    crash under certain conditions when the image is rotated a few
    times (bnc#723614)
* Fri Oct 21 2011 gber@opensuse.org
- install HTML documentation under /usr/share/xfce4/ristretto/html
* Mon Oct 17 2011 gber@opensuse.org
- update to version 0.2.0
  - improve open-file and close-file behaviour
  - hide thumbnailbar when no images are opened
  - add option to merge the 2 toolbars into one
  - make open-entire-folder the default and remove the option from
    the preferences dialog
  - show the toolbar when going to fullscreen-mode without any
    open images
  - reduce timeout before toolbar is hidden from 3000 to 500ms
  - bugfixes
* Fri Oct  7 2011 gber@opensuse.org
- update to version 0.1.1
  - included all previous patches
- removed ristretto-0.1.0-fix-missing-retvals.patch and
  ristretto-0.1.0-fix-underlinking.patch
* Thu Oct  6 2011 gber@opensuse.org
- update to version 0.1.0
  - add 'Clear private data' dialog, for clearing the recently-used
    list
  - improve the 'Set Wallpaper' dialog for setting the wallpaper on
    xfdesktop
  - add an option to 'inverse' the zoom-direction when scrolling
  - set the maximum render-quality to the screen-size, this
    improves the render-speed and reduces the memory-usage of
    ristretto
  - limit the maximum-scale to 400%% or the window-size (whichever
    comes last)
  - limit the minimum-scale to an image-size of 32x32 pixels
  - improve the subpixbuf size calculation to reduce the anoying
    black-borders when zooming in dramatically
  - add tooltip to the delete button
  - add files opened from the cli to the recently-used list
  - move the image-iterator to the next image instead of the
    previous image when closing
  - open the first image from a folder when opening a folder from
    the recently-used-items list
  - re-implement the file-properties dialog, open thunar's
    properties dialog when thunar is available, add a 'fallback'
    dialog for when thunar is not available
- added ristretto-0.1.0-fix-missing-retvals.patch which fixes
  missing return statements and a typo
- added ristretto-0.1.0-fix-underlinking.patch in order to
  explicitly link against libm and libX11
- dropped obsolete ristretto-0.0.91-honor-docdir.patch,
  ristretto-0.0.93-fix-missing-include.patch
* Tue Mar  8 2011 gber@opensuse.org
- update to version 0.0.93:
  - removed dependency on libxfcegui4
  - restore size of thumbnail-bar
  - save and restore image zoom-state when navigating
  - implement 'Ready' signal-handler for thumbnailer-spec
  - correctly cleaned up the references to xfconf
- added patch tags
- added ristretto-0.0.93-fix-missing-include.patch in order to adds
  a missing include (bxo#7391)
* Thu Feb 17 2011 gber@opensuse.org
- call %%desktop_database_post/un
- call %%icon_theme_cache_post/un
* Sat Dec 25 2010 gber@opensuse.org
- added ristretto-0.0.91-add-more-mime-types.patch in order to
  claim support for all image types supported by GDK
- do not install package documentation under /usr/share/doc
  - added ristretto-0.0.91-honor-docdir.patch in order to make
    proper use use of ./configure --docdir
- remove unsupported locales
- improved summary/descriptions
* Thu Dec  2 2010 prusnak@opensuse.org
- updated to 0.0.91
  - Remove dependency on thunar
  - Port to GIO instead of thunarvfs
  - Add option to select maximum render quality (can improve performance at the
    cost of image-quality)
  - Store the settings in xfconf
  - Add option to completely disable the image-cache
  - Use dbus-thumbnailing spec to generate thumbnails
  - Add buttons to delete the image from disk
  - Restyle the toolbars to make room for more usefull options
  - Save position and size of thumbnail-bar
* Tue May 19 2009 prusnak@suse.cz
- updated to 0.0.22
  * Fix memleak (I should've unref-ed the animation-iter)
  * Improve cache size calculation
* Fri Feb 27 2009 prusnak@suse.cz
- updated to 0.0.21
  * Fix segfault when exif-data is missing (Bug #4599)
  * Fix detection of xfdesktop
  * Remove xfconf compile-time dependency, make it a runtime one on
    xfconf-query
  * Fix segfault caused by invalid marshallers.
  * Improved history behaviour (push 'old' images to the top when
    they are visited again)
  * Improved preloading
  * Fixed segfault caused by a reference-count bug.
* Tue Nov 11 2008 prusnak@suse.cz
- fix segfault when no EXIF data present (exif.patch)
* Wed Jun 18 2008 prusnak@suse.cz
- updated to 0.0.20
  * Add limits so that images are not scrolled outside the thumbnail-bar
    boundaries (Fix bug introduced with 0.0.19)
  * Add 'Close All' menu item.
  * Add command-line option for opening in full-screen mode (Bug #4077)
  * Add command-line option for opening in slideshow mode (Bug #4077)
  * Add option to show/hide thumbnails during slideshow. (Bug #4076)
  * Do not include Generic Name to the Name field, this makes some menu
    implementations look broken (Bug #4085)
* Wed Jun 18 2008 prusnak@suse.cz
- updated to 0.0.19
  * Add option to change the wallpaper with xfdesktop >= 4.5
  * Detect if xfdesktop is running
  * Scroll through images when using the scroll-button, rather then
    changing the active one.
  * Open the desired image BEFORE loading the rest of the folder, this
    reduces the time it takes to display the initial image.
* Thu Mar 27 2008 prusnak@suse.cz
- update to 0.0.18
  * Improved zoom-box
  * Added rudimentary drag-n-drop support for opening images
  * Removed duplicate code for opening files and folders, moved this
    to the navigator (Bug #3866)
  * Open files and folders when the main-loop is running, this way the
    window is already usable before the images are being opened.
  * Add configuration option to toggle the folowing feature:
  - Prevent images to be scaled beyond 100%% when maximizing the window
  - Resize images to fit to the window when restoring the window from
    maximize state.
  * Prevent GUI freezes when opening a folder with a lot of files in
    them.
  * Fix segfaults when closing ristretto while it is opening a folder.
  * Restore of auto-center when clicking on a thumbnail.
  * The Statusbar displays some feedback when opening files.
* Sun Feb 17 2008 bwalle@suse.de
- update to 0.0.17
  o Fix segfault when scrolling over the picture-viewer
  o Fix event-window issues overlaying the 1:1 and fit zoom-
    buttons, now the zoom-buttons keep working when the thumbnails
    scroll behind the toolbar
  * Improve behaviour of thumbnails.
  * Fix desktop-file syntax
* Tue Jan 29 2008 prusnak@suse.cz
- update to 0.0.16
  * Add zoom-mode support (remember zoom-mode across images)
  * New thumbnail-bar
  * Add drag support
  * New thumbnail objects (better themeable)
  * Add tooltip support (atm with gtk+-2.12 only)
  * Improve the caching behaviour
  * Add configuration option for image-cache size
  * Improve the creation of file-monitor handles, only create one
    file-monitor when opening a directory. This works around limitations
    of fam and gamin, and it allows the detection of new images inside
    this folder.
* Sun Dec  9 2007 bwalle@suse.de
- update to 0.0.15
  o Fix store and load functions for background-color, functions
    used
  o Fix opening of relative paths.
  o Redraw the picture-viewer after setting a new background-color
  o Improve box-zoom
* Sat Dec  1 2007 bwalle@suse.de
- update to 0.0.14
  o Add keyboard-shortcuts for rotating
  o Fix modification of bg-color using preferences dialog
  o Fix thumbnail-scaling when thumbnail is first generated
  o Refresh when new images are added and within visible range of
    the thumbnail-viewer
  o Improve behaviour when opening images from cli.
* Tue Nov 27 2007 bwalle@suse.de
- update to 0.0.13
  o Fix segfault when running ristretto with unknown cli-options.
  o Add rudimentary box-zoom (use ctrl-click to make use it).
  o Use gtk-style background-color by default.
  o Allow modification of background-color.
  o Add Rotate sub-menu and buttons.
  o Add Zooming sub-menu and buttons.
  o Override picture-viewer bg-color when switching to fullscreen
    mode.
* Sat Nov 17 2007 bwalle@suse.de
- update to 0.0.12
  o Fix High CPU-usage
  o Improve performance when new images are added to the navigator
  o Emit iter_changed signal when navigator is cleared.
  o Leave fullscreen mode by using 'Escape' key
  o Fix toolbar always visible after leaving fullscreen mode
  o Fix titlebar string
  o Fix open file from CLI
* Wed Nov  7 2007 prusnak@suse.cz
- updated to 0.0.11
  * Improve performance when zooming with mouse-wheel
  * Improve performance when dragging the image around
  * Add some comments
  * Improve preferences dialog
* Tue Nov  6 2007 prusnak@suse.cz
- updated to 0.0.10
  * Move image loading to navigator (to aid preloading and cache)
  * Add Preferences dialog
  * Add file-properties dialog (uses d-bus and thunar for now)
  * Add preloading
  * add thunar-vfs-monitor support (images are now reloaded when they are modified)
  * Fix rendering bug
* Tue Oct 16 2007 bwalle@suse.de
- updated to 0.0.9
  o Fix EXIF orientation (was broken with previous release)
  o Add right mouse click menu
  o Add drag move when zoomed (still experimental)
* Sun Oct 14 2007 bwalle@suse.de
- updated to 0.0.8
  o Add support for animated images (like .gif and .mng)
  o Improve load-times
  o Improve responsiveness when loading images
  o Fix memory leak when opening files / folders
* Tue Oct  2 2007 prusnak@suse.cz
- updated to 0.0.7
  * fix segfault in navigation.c
  * fix broken if statements in main_window.c
* Sun Sep 30 2007 bwalle@suse.de
- updated to 0.0.6
  o Add EXIF support for detecting the image-orientation
  o Improve the paint behaviour, do not paint the same pixel twice
  o When switching files, fix the timeout and darken the original
    image until the timeout is exceeded.
* Fri Sep 14 2007 prusnak@suse.cz
- updated to 0.0.5
- removed desktop.patch
* Sat Sep  8 2007 bwalle@suse.de
- updated to 0.0.4
* Mon Sep  3 2007 bwalle@suse.de
- updated to 0.0.3
* Tue Aug 28 2007 prusnak@suse.cz
- created package (initial version 0.0.1)
